[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4608653.svg)](https://doi.org/10.5281/zenodo.4608653)


Citation
========

If you use *bmi-topography*, please cite it with:

Piper, M (2021). CSDMS Topography data component (v0.3.1). Zenodo. http://doi.org/10.5281/zenodo.4608653
